@@ -1,6 +1,6 @@
 #' Screen radionuclide data to find matches to decay mode, half-life, and total emission energy
 #'
-#' @description Provides a set of radionuclides matching screening criteria. This is a limited screening based on average energy per transformation. Consider [search_phot_by_E], [search_alpha_by_E], and [search_beta_by_E] for spectroscopic measurement matching. For best results, assign results to a named object, then view the object.
+#' @description Provides a set of radionuclides matching screening criteria. This is a limited screening based on average energy per transformation. Consider [search_phot_by_E], [search_alpha_by_E], and [search_beta_by_E] for spectroscopic measurement matching.
 #'
 #' @family radionuclides
 #'
@@ -19,8 +19,8 @@
 #' @param min_E_photon default = NULL. This will be used to screen the index for average photon energy per decay, including all decay branches.
 #' @return data frame of radionuclide data from the RadData package index data (RadData::ICRP_07.NDX), matching search criteria.
 #' @examples
-#' RNs_selected <- RN_index_screen(dk_mode = "SF")
-#' RNs_selected <- RN_index_screen(dk_mode = "IT", max_half_life_seconds = 433 * 3.15e7)
+#' RN_index_screen(dk_mode = "SF")
+#' RN_index_screen(dk_mode = "IT", max_half_life_seconds = 433 * 3.15e7)
 #' @export
 RN_index_screen <-
   function(dk_mode = NULL,
@@ -60,5 +60,5 @@ RN_index_screen <-
     if (!is.null(min_E_photon)) {
       RNs_selected <- RNs_selected[which(RNs_selected$E_photon > min_E_photon), ]
     }
-    RNs_selected[order(RNs_selected$decay_constant, decreasing = TRUE), ]
+    RNs_selected[order(RNs_selected$decay_constant, decreasing = TRUE), c(1:4, 21:23)]
   }
